import os, pygame

from OpenGL.GL import *

import texture
from data import get_path

font_cache = {}

default_fontname = 'DejaVuSans.ttf'
default_fontsize = 16
def render_text(name, size, text, color):
	font = font_cache.get((name, size))
	if not font:
		if not name:
			name = default_fontname

		if not size:
			size = default_fontsize

		name = get_path(os.path.join('fonts', name))
		font = pygame.font.Font(name, size)
		font_cache[(name, size)] = font

	return font.render(text, 1, color)

class Text (object):
	def __init__(self, text, font=None, size=32, color=(0, 0, 0)):
		self.text = text
		surf = render_text(font, size, text, color)
		self.w, self.h = surf.get_size()

		self.left = (1024 - self.w) / 2
		self.right = self.left + self.w

		self.list = glGenLists(1)
		self.tex = texture.Texture()
		self.tex.set(surf)

		glNewList(self.list, GL_COMPILE)

		glMatrixMode(GL_PROJECTION)
		glPushMatrix()
		glLoadIdentity()
		glOrtho(0, 1024, 768, 0, -1, 1)
		glMatrixMode(GL_MODELVIEW)

		glPushAttrib(GL_ENABLE_BIT | GL_COLOR_BUFFER_BIT)
		glDisable(GL_DEPTH_TEST)
		glDisable(GL_FOG)
		glEnable(GL_BLEND)
		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
		
		self.tex.select()
		glBegin(GL_QUADS)
		glTexCoord2f(0, 0)
		glVertex3f(0, 0, 0)
		glTexCoord2f(0, 1)
		glVertex3f(0, self.h, 0)
		glTexCoord2f(1, 1)
		glVertex3f(self.w, self.h, 0)
		glTexCoord2f(1, 0)
		glVertex3f(self.w, 0, 0)
		glEnd()

		glMatrixMode(GL_PROJECTION)
		glPopMatrix()
		glMatrixMode(GL_MODELVIEW)

		glPopAttrib()
		glEndList()

	def render(self, x, y):
		glPushMatrix()
		glLoadIdentity()
		glTranslatef(x, y, 0)
		glCallList(self.list)
		glPopMatrix()
	
	def free(self):
		self.tex.free()
