import pygame

from OpenGL.GL import *

import world, gui, config

class Message (object):
	max_age = 10.

	def __init__(self, text, font=None, size=32):
		self.text = gui.Text(text, font, size)
		self.time = 0.
		
		self.sw, self.sh = config.screen_size

		self.y = self.sh / 2
	
	def think(self):
		self.time += 0.1
		self.y -= 2.

		if self.y < -self.text.h:
			self.text.free()
			self.text = None
			return 0

		return 1
			
	def render(self):
		glPushAttrib(GL_CURRENT_BIT)
		glColor4f(1, 1, 1, min(self.time, 1))
		self.text.render((self.sw - self.text.w) / 2, self.y)
		glPopAttrib()

class Quest (object):
	def __init__(self):
		self.time = 0.

		self.texts = [
			(0.5, 'When you woke up...'),
			(1.5, 'you found yourself standing on a gigantic feather'),
			(1.7, 'amidst howling wind, while falling from the skies down.'),
			(4.0, 'Use arrow keys to control the feather.'),
			(4.2, 'Use red upwards air draughts to gain speed and altitude.'),
			(4.4, 'Avoid blue downdraughts.')
		]

		self.last_message = 0.
		self.messages = []

	def think(self):
		self.time += 0.01

		for t, text in self.texts:
			if self.last_message < t < self.time:
				m = Message(text)
				self.messages.append(m)
				self.last_message = t

		self.messages = [m for m in self.messages if m.think()]

	def render(self):
		for m in self.messages:
			m.render()

