import pygame
from pygame import *

from OpenGL.GL import *
from OpenGL.GLU import *

import scenes, config, sounds

class SceneManager (object):
	scenes = {
		'start': scenes.StartScene,
		'title': scenes.TitleScene,
		'flight': scenes.FlightScene,
		'pause': scenes.PauseScene,
		'gameover': scenes.GameOverScene,
	}

	start_scene = 'start'

	def __init__(self):
		self.scene = None
	
	def init(self):
		pygame.mixer.pre_init(44100)
		pygame.init()

		self.display = pygame.display.set_mode(config.screen_size, OPENGL | DOUBLEBUF)
		glMatrixMode(GL_PROJECTION)
		glLoadIdentity()

		aspect = float(config.screen_size[0]) / config.screen_size[1]
		gluPerspective(45, aspect, 1, 10000)
		glMatrixMode(GL_MODELVIEW)
		glEnable(GL_TEXTURE_2D)
		glEnable(GL_DEPTH_TEST)

		sounds.preload_samples()

	def switch_scene(self, next, args):
		if isinstance(next, basestring):
			self.scene = self.scenes[next](self, *args)
			self.scene.init()
		else:
			self.scene = next

	def run(self):
		clock = pygame.time.Clock()

		self.running = 1
		self.switch_scene(self.start_scene, ())

		while self.running:
			clock.tick(25)

			if pygame.event.get(QUIT) or not self.scene:
				break

			next = self.scene.think()
			if next:
				next, args = next
				if next == 'exit':
					self.running = False
				else:
					self.switch_scene(next, args)
					continue

			self.scene.render()
			
			pygame.display.flip()
		
def run():
	"""Run the game.
	"""
	sm = SceneManager()
	sm.init()
	sm.run()


if __name__ == '__main__':
	run()
